@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2010-2013 LabKey Corporation
+# Copyright (c) 2010-2014 LabKey Corporation
 # 
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -42,9 +42,7 @@ header <- basicTextGatherer()
 
 ## Http get
 handle <- getCurlHandle()
-myopts <- curlOptions(writefunction=reader$update, headerfunction=header$update, netrc=1, 
-	ssl.verifyhost=FALSE, ssl.verifypeer=FALSE, followlocation=TRUE, httpauth=1L
-	)
+myopts <- curlOptions(netrc=1, writefunction=reader$update, headerfunction=header$update, .opts=c(labkey.curlOptions()))
 
 ## Support user-settable options for debugging and setting proxies etc
 if(exists(".lksession"))
@@ -70,13 +68,13 @@ status <- getCurlInfo(handle)$response.code
 message <- h$statusMessage
 
 if(status==500)
-{decode <- fromJSON2(mydata); message <- decode$exception; stop(paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))}
+{decode <- fromJSON(mydata); message <- decode$exception; stop(paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))}
 if(status>=400)
 {
   contTypes <- which(names(h)=='Content-Type')
   if(length(contTypes)>0 && (tolower(h[contTypes[1]])=="application/json;charset=utf-8" || tolower(h[contTypes[2]])=="application/json;charset=utf-8"))
   {
-    decode <- fromJSON2(mydata);
+    decode <- fromJSON(mydata);
     message<-decode$exception;
     stop (paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))
   } else
@@ -85,7 +83,7 @@ if(status>=400)
   }
 }
 
-decode <- fromJSON2(mydata)
+decode <- fromJSON(mydata)
 curfld <- decode
 allpaths <- matrix(data=c(curfld$name, curfld$path, paste(curfld$effectivePermissions, collapse=",")), nrow=1, ncol=3, byrow=TRUE)
 todo <- curfld$children[]
