@@ -1,5 +1,5 @@
 ##
-#  Copyright (c) 2010-2013 LabKey Corporation
+#  Copyright (c) 2010-2014 LabKey Corporation
 # 
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -72,7 +72,7 @@ getQueryLists <- function(baseUrl, folderPath, schemaName, queryName=NULL)
 	## Set options
 	reader <- basicTextGatherer()
 	header <- basicTextGatherer()
-	myopts <- curlOptions(writefunction=reader$update, headerfunction=header$update, netrc=1, ssl.verifyhost=FALSE, ssl.verifypeer=FALSE, followlocation=TRUE)
+    myopts <- curlOptions(netrc=1, writefunction=reader$update, headerfunction=header$update, .opts=c(labkey.curlOptions()))
 
 	## Support user-settable options for debuggin and setting proxies etc
 	if(exists(".lksession"))
@@ -93,13 +93,13 @@ getQueryLists <- function(baseUrl, folderPath, schemaName, queryName=NULL)
 	message <- h$statusMessage
 
 	if(status==500)
-	{decode <- fromJSON2(mydata); message <- decode$exception; stop(paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))}
+	{decode <- fromJSON(mydata); message <- decode$exception; stop(paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))}
 	if(status>=400)
 	{
 	    contTypes <- which(names(h)=='Content-Type')
 	    if(length(contTypes)>0 && (tolower(h[contTypes[1]])=="application/json;charset=utf-8" || tolower(h[contTypes[2]])=="application/json;charset=utf-8"))
 		{
-		    decode <- fromJSON2(mydata);
+		    decode <- fromJSON(mydata);
 		    message<-decode$exception;
 		    stop (paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))
         } else
@@ -108,7 +108,7 @@ getQueryLists <- function(baseUrl, folderPath, schemaName, queryName=NULL)
         }
     }
 
-	decode <- fromJSON2(mydata)
+	decode <- fromJSON(mydata)
 	qs <- decode[[queryObjType]]
 
 	dmall <- matrix(nrow=0, ncol=2, byrow=TRUE)
